@@ -190,13 +190,13 @@ impl_trait!(Ticker, HuobiWSClient, subscribe_ticker, "detail", to_raw_channel);
 #[rustfmt::skip]
 impl_trait!(BBO, HuobiWSClient, subscribe_bbo, "bbo", to_raw_channel);
 #[rustfmt::skip]
-impl_trait!(OrderBookSnapshot, HuobiWSClient, subscribe_orderbook_snapshot, "depth.step0", to_raw_channel);
+impl_trait!(OrderBookSnapshot, HuobiWSClient, subscribe_orderbook_snapshot, "depth.step7", to_raw_channel);
 
 impl<'a> OrderBook for HuobiWSClient<'a> {
     fn subscribe_orderbook(&self, pairs: &[String]) {
         let pair_to_raw_channel = |pair: &String| {
             format!(
-                r#"{{"sub": "market.{}.depth.size_150.high_freq","data_type":"incremental","id": "crypto-ws-client"}}"#,
+                r#"{{"sub": "market.{}.depth.size_20.high_freq","data_type":"incremental","id": "crypto-ws-client"}}"#,
                 pair
             )
         };
@@ -357,7 +357,7 @@ impl<'a> OrderBook for HuobiSpotWSClient<'a> {
         if self.client.client.url.as_str() == "wss://api.huobi.pro/feed"
             || self.client.client.url.as_str() == "wss://api-aws.huobi.pro/feed"
         {
-            let pair_to_raw_channel = |pair: &String| to_raw_channel("mbp.150", pair);
+            let pair_to_raw_channel = |pair: &String| to_raw_channel("mbp.20", pair);
 
             let channels = pairs
                 .iter()
@@ -386,7 +386,8 @@ macro_rules! impl_orderbook_snapshot {
     };
 }
 
-impl_orderbook_snapshot!(HuobiSpotWSClient);
+#[rustfmt::skip]
+impl_trait!(OrderBookSnapshot, HuobiSpotWSClient, subscribe_orderbook_snapshot, "depth.step1", to_raw_channel);
 impl_orderbook_snapshot!(HuobiFutureWSClient);
 impl_orderbook_snapshot!(HuobiInverseSwapWSClient);
 impl_orderbook_snapshot!(HuobiLinearSwapWSClient);
